==> ejc-lz-impl-3.0.0-20220509.024412-92-sources.jar: com/ejianc/business/base/vo/MaterialVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 原材料
 * 
 * @author generator
 * 
 */
public class MaterialVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编号
    private String name; // 原材料名称
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private String operatorId; // 经办人id
    private String operatorName; // 经办人名称
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private Long categoryId; // 材料类别主键
    private Long varietiesId; // 材料品种主键
    private Long specId; // 材料规格主键
    private String taxAttributesId; // 税收属性
    private String inspectionModeId; // 检验方式
    private BigDecimal discountRateId; // 扣率
    private BigDecimal decimalPlacesId; // 小数位
    private String cdefine1; // 
    private String cdefine2; // 
    private String cdefine3; // 
    private String cdefine4; // 
    private String cdefine5; // 
    private String cdefine6; // 
    private String cdefine7; // 
    private String cdefine8; // 
    private String cdefine9; // 
    private String cdefine10; // 
    private Integer cdefine11; // 
    private Integer cdefine12; // 
    private BigDecimal cdefine13; // 
    private BigDecimal cdefine14; // 
    private Date cdefine15; // 
    private Date cdefine16; // 
    private String categoryName; // 类别名称
    private String varietiesName; // 品种名称
    private String specName; // 型号名称
    private BigDecimal inventoryUp; // 库存上限
    private BigDecimal inventoryDown; // 库存下限
    private BigDecimal taxRate; // 税率
    private String mareialProperty; // 原材料属性
    private String remark; // 备注
    private Integer isCheck; // 是否一车一检:0 是 1 否
    private Integer checkNumber; // 检吨数
    private Integer hideFlag; // 隐藏标志：0 显示 1 隐藏
    private BigDecimal lossNumber; // 损耗数
    private BigDecimal referencePrice; // 参考价格

    private String errorMsg; // 导入错误信息

    public BigDecimal getReferencePrice() {
        return referencePrice;
    }

    public void setReferencePrice(BigDecimal referencePrice) {
        this.referencePrice = referencePrice;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    @ReferSerialTransfer(referCode="MaterialCategoryRef")
    public Long getCategoryId() {
        return categoryId;
    }

    @ReferDeserialTransfer
    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    @ReferSerialTransfer(referCode="MaterialVarietiesRef")
    public Long getVarietiesId() {
        return varietiesId;
    }

    @ReferDeserialTransfer
    public void setVarietiesId(Long varietiesId) {
        this.varietiesId = varietiesId;
    }
    @ReferSerialTransfer(referCode="MaterialSpecRef")
    public Long getSpecId() {
        return specId;
    }

    @ReferDeserialTransfer
    public void setSpecId(Long specId) {
        this.specId = specId;
    }

    public String getTaxAttributesId() {
        return taxAttributesId;
    }

    public void setTaxAttributesId(String taxAttributesId) {
        this.taxAttributesId = taxAttributesId;
    }

    public String getInspectionModeId() {
        return inspectionModeId;
    }

    public void setInspectionModeId(String inspectionModeId) {
        this.inspectionModeId = inspectionModeId;
    }

    public BigDecimal getDiscountRateId() {
        return discountRateId;
    }

    public void setDiscountRateId(BigDecimal discountRateId) {
        this.discountRateId = discountRateId;
    }

    public BigDecimal getDecimalPlacesId() {
        return decimalPlacesId;
    }

    public void setDecimalPlacesId(BigDecimal decimalPlacesId) {
        this.decimalPlacesId = decimalPlacesId;
    }

    public String getCdefine1() {
        return cdefine1;
    }

    public void setCdefine1(String cdefine1) {
        this.cdefine1 = cdefine1;
    }
    public String getCdefine2() {
        return cdefine2;
    }

    public void setCdefine2(String cdefine2) {
        this.cdefine2 = cdefine2;
    }
    public String getCdefine3() {
        return cdefine3;
    }

    public void setCdefine3(String cdefine3) {
        this.cdefine3 = cdefine3;
    }
    public String getCdefine4() {
        return cdefine4;
    }

    public void setCdefine4(String cdefine4) {
        this.cdefine4 = cdefine4;
    }
    public String getCdefine5() {
        return cdefine5;
    }

    public void setCdefine5(String cdefine5) {
        this.cdefine5 = cdefine5;
    }
    public String getCdefine6() {
        return cdefine6;
    }

    public void setCdefine6(String cdefine6) {
        this.cdefine6 = cdefine6;
    }
    public String getCdefine7() {
        return cdefine7;
    }

    public void setCdefine7(String cdefine7) {
        this.cdefine7 = cdefine7;
    }
    public String getCdefine8() {
        return cdefine8;
    }

    public void setCdefine8(String cdefine8) {
        this.cdefine8 = cdefine8;
    }
    public String getCdefine9() {
        return cdefine9;
    }

    public void setCdefine9(String cdefine9) {
        this.cdefine9 = cdefine9;
    }
    public String getCdefine10() {
        return cdefine10;
    }

    public void setCdefine10(String cdefine10) {
        this.cdefine10 = cdefine10;
    }
    public Integer getCdefine11() {
        return cdefine11;
    }

    public void setCdefine11(Integer cdefine11) {
        this.cdefine11 = cdefine11;
    }
    public Integer getCdefine12() {
        return cdefine12;
    }

    public void setCdefine12(Integer cdefine12) {
        this.cdefine12 = cdefine12;
    }
    public BigDecimal getCdefine13() {
        return cdefine13;
    }

    public void setCdefine13(BigDecimal cdefine13) {
        this.cdefine13 = cdefine13;
    }
    public BigDecimal getCdefine14() {
        return cdefine14;
    }

    public void setCdefine14(BigDecimal cdefine14) {
        this.cdefine14 = cdefine14;
    }
    public Date getCdefine15() {
        return cdefine15;
    }

    public void setCdefine15(Date cdefine15) {
        this.cdefine15 = cdefine15;
    }
    public Date getCdefine16() {
        return cdefine16;
    }

    public void setCdefine16(Date cdefine16) {
        this.cdefine16 = cdefine16;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getVarietiesName() {
        return varietiesName;
    }

    public void setVarietiesName(String varietiesName) {
        this.varietiesName = varietiesName;
    }
    public String getSpecName() {
        return specName;
    }

    public void setSpecName(String specName) {
        this.specName = specName;
    }

    public BigDecimal getInventoryUp() {
        return inventoryUp;
    }

    public void setInventoryUp(BigDecimal inventoryUp) {
        this.inventoryUp = inventoryUp;
    }

    public BigDecimal getInventoryDown() {
        return inventoryDown;
    }

    public void setInventoryDown(BigDecimal inventoryDown) {
        this.inventoryDown = inventoryDown;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public String getMareialProperty() {
        return mareialProperty;
    }

    public void setMareialProperty(String mareialProperty) {
        this.mareialProperty = mareialProperty;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getIsCheck() {
        return isCheck;
    }

    public void setIsCheck(Integer isCheck) {
        this.isCheck = isCheck;
    }

    public Integer getCheckNumber() {
        return checkNumber;
    }

    public void setCheckNumber(Integer checkNumber) {
        this.checkNumber = checkNumber;
    }

    public Integer getHideFlag() {
        return hideFlag;
    }

    public void setHideFlag(Integer hideFlag) {
        this.hideFlag = hideFlag;
    }

    public BigDecimal getLossNumber() {
        return lossNumber;
    }

    public void setLossNumber(BigDecimal lossNumber) {
        this.lossNumber = lossNumber;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
}

==> ejc-lz-impl-3.0.0-20220830.080126-153-sources.jar: com/ejianc/business/base/vo/MaterialVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 原材料
 * 
 * @author generator
 * 
 */
public class MaterialVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编号
    private String name; // 原材料名称
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private String operatorId; // 经办人id
    private String operatorName; // 经办人名称
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private Long categoryId; // 材料类别主键
    private Long varietiesId; // 材料品种主键
    private Long specId; // 材料规格主键
    private String taxAttributesId; // 税收属性
    private String inspectionModeId; // 检验方式
    private BigDecimal discountRateId; // 扣率
    private String decimalPlacesId; // 小数位
    private String categoryName; // 类别名称
    private String varietiesName; // 品种名称
    private String specName; // 型号名称
    private BigDecimal inventoryUp; // 库存上限
    private BigDecimal inventoryDown; // 库存下限
    private BigDecimal taxRate; // 税率
    private String mareialProperty; // 原材料属性
    private String remark; // 备注
    private Integer isCheck; // 是否一车一检:0 是 1 否
    private Integer checkNumber; // 检吨数
    private Integer hideFlag; // 隐藏标志：0 显示 1 隐藏
    private BigDecimal lossNumber; // 损耗数
    private BigDecimal referencePrice; // 参考价格

    private String errorMsg; // 导入错误信息

    public BigDecimal getReferencePrice() {
        return referencePrice;
    }

    public void setReferencePrice(BigDecimal referencePrice) {
        this.referencePrice = referencePrice;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    @ReferSerialTransfer(referCode="MaterialCategoryRef")
    public Long getCategoryId() {
        return categoryId;
    }

    @ReferDeserialTransfer
    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    @ReferSerialTransfer(referCode="MaterialVarietiesRef")
    public Long getVarietiesId() {
        return varietiesId;
    }

    @ReferDeserialTransfer
    public void setVarietiesId(Long varietiesId) {
        this.varietiesId = varietiesId;
    }
    @ReferSerialTransfer(referCode="MaterialSpecRef")
    public Long getSpecId() {
        return specId;
    }

    @ReferDeserialTransfer
    public void setSpecId(Long specId) {
        this.specId = specId;
    }

    public String getTaxAttributesId() {
        return taxAttributesId;
    }

    public void setTaxAttributesId(String taxAttributesId) {
        this.taxAttributesId = taxAttributesId;
    }

    public String getInspectionModeId() {
        return inspectionModeId;
    }

    public void setInspectionModeId(String inspectionModeId) {
        this.inspectionModeId = inspectionModeId;
    }

    public BigDecimal getDiscountRateId() {
        return discountRateId;
    }

    public void setDiscountRateId(BigDecimal discountRateId) {
        this.discountRateId = discountRateId;
    }

    public String getDecimalPlacesId() {
        return decimalPlacesId;
    }

    public void setDecimalPlacesId(String decimalPlacesId) {
        this.decimalPlacesId = decimalPlacesId;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getVarietiesName() {
        return varietiesName;
    }

    public void setVarietiesName(String varietiesName) {
        this.varietiesName = varietiesName;
    }
    public String getSpecName() {
        return specName;
    }

    public void setSpecName(String specName) {
        this.specName = specName;
    }

    public BigDecimal getInventoryUp() {
        return inventoryUp;
    }

    public void setInventoryUp(BigDecimal inventoryUp) {
        this.inventoryUp = inventoryUp;
    }

    public BigDecimal getInventoryDown() {
        return inventoryDown;
    }

    public void setInventoryDown(BigDecimal inventoryDown) {
        this.inventoryDown = inventoryDown;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public String getMareialProperty() {
        return mareialProperty;
    }

    public void setMareialProperty(String mareialProperty) {
        this.mareialProperty = mareialProperty;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getIsCheck() {
        return isCheck;
    }

    public void setIsCheck(Integer isCheck) {
        this.isCheck = isCheck;
    }

    public Integer getCheckNumber() {
        return checkNumber;
    }

    public void setCheckNumber(Integer checkNumber) {
        this.checkNumber = checkNumber;
    }

    public Integer getHideFlag() {
        return hideFlag;
    }

    public void setHideFlag(Integer hideFlag) {
        this.hideFlag = hideFlag;
    }

    public BigDecimal getLossNumber() {
        return lossNumber;
    }

    public void setLossNumber(BigDecimal lossNumber) {
        this.lossNumber = lossNumber;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
}
